@@ -6,23 +6,18 @@ BEGIN {
   $Path::IsDev::Heuristic::AUTHORITY = 'cpan:KENTNL';
 }
 {
-  $Path::IsDev::Heuristic::VERSION = '0.5.0';
+  $Path::IsDev::Heuristic::VERSION = '0.6.0';
 }
 
 # ABSTRACT: Heuristic Base class
 
 
-sub _croak   { require Carp;         goto &Carp::croak }
-sub _blessed { require Scalar::Util; goto &Scalar::Util::blessed }
-sub _debug   { require Path::IsDev;  goto &Path::IsDev::debug }
 
+sub _croak { require Carp;        goto &Carp::croak }
+sub _debug { require Path::IsDev; goto &Path::IsDev::debug }
 
-sub name {
-  my $name = shift;
-  $name = _blessed($name) if _blessed($name);
-  $name =~ s/\APath::IsDev::Heuristic:/:/msx;
-  return $name;
-}
+use Role::Tiny::With;
+with 'Path::IsDev::Role::Heuristic';
 
 
 sub _file_matches {
@@ -89,19 +84,16 @@ Path::IsDev::Heuristic - Heuristic Base class
 
 =head1 VERSION
 
-version 0.5.0
+version 0.6.0
+
+=head1 SYNOPSIS
+
+This module exists mostly as a compatibility shim.
+
+All new Heuristics should simply C<with> the applicable role.
 
 =head1 METHODS
 
-=head2 C<name>
-
-Returns the name to use in debugging.
-
-By default, this is derived from the classes name
-with the C<PIDH> prefix removed:
-
-    Path::IsDev::Heuristic::Tool::Dzil->name() # → ::Tool::Dzil
-
 =head2 C<matches>
 
 Determines if the current heuristic matches a given path
@@ -131,7 +123,8 @@ Glue layer between C<< ->matches >> and C<< ->dirs >>
 
 {
     "namespace":"Path::IsDev::Heuristic",
-    "interface":"single_class"
+    "interface":"single_class",
+    "does":"Path::IsDev::Role::Heuristic"
 }
 
 
