@@ -6,14 +6,15 @@ BEGIN {
   $Path::IsDev::Heuristic::MYMETA::AUTHORITY = 'cpan:KENTNL';
 }
 {
-  $Path::IsDev::Heuristic::MYMETA::VERSION = '0.5.0';
+  $Path::IsDev::Heuristic::MYMETA::VERSION = '0.6.0';
 }
 
 # ABSTRACT: Determine if a path contains MYMETA.(json|yml)
 
 
 
-use parent 'Path::IsDev::Heuristic';
+use Role::Tiny::With;
+with 'Path::IsDev::Role::Heuristic::AnyFile';
 
 
 sub files { return qw( MYMETA.json MYMETA.yml ) }
@@ -32,7 +33,7 @@ Path::IsDev::Heuristic::MYMETA - Determine if a path contains MYMETA.(json|yml)
 
 =head1 VERSION
 
-version 0.5.0
+version 0.6.0
 
 =head1 DESCRIPTION
 
@@ -55,7 +56,7 @@ Files relevant to this heuristic
 {
     "namespace":"Path::IsDev::Heuristic::MYMETA",
     "interface":"single_class",
-    "inherits":"Path::IsDev::Heuristic"
+    "does":"Path::IsDev::Role::Heuristic::AnyFile"
 }
 
 
