@@ -6,13 +6,14 @@ BEGIN {
   $Path::IsDev::Heuristic::Makefile::AUTHORITY = 'cpan:KENTNL';
 }
 {
-  $Path::IsDev::Heuristic::Makefile::VERSION = '0.5.0';
+  $Path::IsDev::Heuristic::Makefile::VERSION = '0.6.0';
 }
 
 
 # ABSTRACT: Determine if a path contains a C<Makefile>
 
-use parent 'Path::IsDev::Heuristic';
+use Role::Tiny::With;
+with 'Path::IsDev::Role::Heuristic::AnyFile';
 
 
 sub files { return qw( GNUmakefile makefile Makefile ) }
@@ -31,7 +32,7 @@ Path::IsDev::Heuristic::Makefile - Determine if a path contains a C<Makefile>
 
 =head1 VERSION
 
-version 0.5.0
+version 0.6.0
 
 =head1 METHODS
 
@@ -48,7 +49,7 @@ Files relevant to this heuristic:
 {
     "namespace":"Path::IsDev::Heuristic::Makefile",
     "interface":"single_class",
-    "inherits":"Path::IsDev::Heuristic"
+    "does":"Path::IsDev::Role::Heuristic::AnyFile"
 }
 
 
