@@ -6,13 +6,15 @@ BEGIN {
   $Path::IsDev::Heuristic::Tool::MakeMaker::AUTHORITY = 'cpan:KENTNL';
 }
 {
-  $Path::IsDev::Heuristic::Tool::MakeMaker::VERSION = '0.5.0';
+  $Path::IsDev::Heuristic::Tool::MakeMaker::VERSION = '0.6.0';
 }
 
 
 # ABSTRACT: Determine if a path is an C<EUMM> Tooled source directory
 
-use parent 'Path::IsDev::Heuristic';
+use Role::Tiny::With;
+
+with 'Path::IsDev::Role::Heuristic::AnyFile';
 
 
 sub files { return qw( Makefile.PL ) }
@@ -31,7 +33,7 @@ Path::IsDev::Heuristic::Tool::MakeMaker - Determine if a path is an C<EUMM> Tool
 
 =head1 VERSION
 
-version 0.5.0
+version 0.6.0
 
 =head1 METHODS
 
@@ -46,7 +48,7 @@ Files relevant to this heuristic:
 {
     "namespace":"Path::IsDev::Heuristic::Tool::MakeMaker",
     "interface":"single_class",
-    "inherits":"Path::IsDev::Heuristic"
+    "does":"Path::IsDev::Role::Heuristic::AnyFile"
 }
 
 
