@@ -6,13 +6,14 @@ BEGIN {
   $Path::IsDev::Heuristic::Tool::ModuleBuild::AUTHORITY = 'cpan:KENTNL';
 }
 {
-  $Path::IsDev::Heuristic::Tool::ModuleBuild::VERSION = '0.5.0';
+  $Path::IsDev::Heuristic::Tool::ModuleBuild::VERSION = '0.6.0';
 }
 
 
 # ABSTRACT: Determine if a path is a Module::Build Source tree
 
-use parent 'Path::IsDev::Heuristic';
+use Role::Tiny::With;
+with 'Path::IsDev::Role::Heuristic::AnyFile';
 
 
 sub files { return qw( Build.PL ) }
@@ -31,7 +32,7 @@ Path::IsDev::Heuristic::Tool::ModuleBuild - Determine if a path is a Module::Bui
 
 =head1 VERSION
 
-version 0.5.0
+version 0.6.0
 
 =head1 METHODS
 
@@ -46,7 +47,7 @@ Files relevant to this heuristic:
 {
     "namespace":"Path::IsDev::Heuristic::Tool::ModuleBuild",
     "interface":"single_class",
-    "inherits":"Path::IsDev::Heuristic"
+    "does":"Path::IsDev::Role::Heuristic::AnyFile"
 }
 
 
