@@ -7,7 +7,7 @@ BEGIN {
   $Path::IsDev::HeuristicSet::AUTHORITY = 'cpan:KENTNL';
 }
 {
-  $Path::IsDev::HeuristicSet::VERSION = '0.5.0';
+  $Path::IsDev::HeuristicSet::VERSION = '0.6.0';
 }
 
 # ABSTRACT: Base class for sets of heuristics
@@ -15,24 +15,10 @@ BEGIN {
 
 
 sub _croak      { require Carp;            goto &Carp::croak }
-sub _use_module { require Module::Runtime; goto &Module::Runtime::use_module }
 sub _debug      { require Path::IsDev;     goto &Path::IsDev::debug }
-sub _com_mn     { require Module::Runtime; goto &Module::Runtime::compose_module_name; }
 
-sub _expand_heuristic {
-  my ( $self, $hn ) = @_;
-  return _com_mn( 'Path::IsDev::Heuristic', $hn );
-}
-
-sub _expand_negative_heuristic {
-  my ( $self, $hn ) = @_;
-  return _com_mn( 'Path::IsDev::NegativeHeuristic', $hn );
-}
-
-sub _load_module {
-  my ( $self, $module ) = @_;
-  return _use_module($module);
-}
+use Role::Tiny::With;
+with 'Path::IsDev::Role::HeuristicSet';
 
 
 sub modules {
@@ -53,24 +39,6 @@ sub modules {
 }
 
 
-sub matches {
-  my ( $self, $result_object ) = @_;
-TESTS: for my $module ( $self->modules ) {
-    $self->_load_module($module);
-    if ( $module->can('excludes') ) {
-      if ( $module->excludes($result_object) ) {
-        _debug( $module->name . q[ excludes path ] . $result_object->path );
-        return;
-      }
-      next TESTS;
-    }
-    next unless $module->matches($result_object);
-    my $name = $module->name;
-    _debug( $name . q[ matched path ] . $result_object->path );
-    return 1;
-  }
-  return;
-}
 
 1;
 
@@ -86,10 +54,14 @@ Path::IsDev::HeuristicSet - Base class for sets of heuristics
 
 =head1 VERSION
 
-version 0.5.0
+version 0.6.0
 
 =head1 SYNOPSIS
 
+This class exists now for compatibility reasons.
+
+You should instead C<with> a C<::Role::HeuristicSet>*
+
     package Path::IsDev::HeuristicSet::Author::KENTNL;
 
     use parent 'Path::IsDev::HeuristicSet';
@@ -120,19 +92,12 @@ Returns the list of fully qualified module names that comprise this heuristic.
 
 Default implementation expands results from C<< ->heuristics >>
 
-=head2 C<matches>
-
-Determine if the C<HeuristicSet> contains a match.
-
-    if( $hs->matches( $result_object ) ) {
-        # one of hs->modules() matched $result_object->path
-    }
-
 =begin MetaPOD::JSON v1.1.0
 
 {
     "namespace":"Path::IsDev::HeuristicSet",
-    "interface":"single_class"
+    "interface":"single_class",
+    "does":"Path::IsDev::Role::HeuristicSet"
 }
 
 
